@@ -151,7 +151,7 @@ def _start(client, bot):
 				line=line.replace("$random"+bot._style[0]+line.split("$random"+bot._style[0])[1].split(bot._style[1])[0]+bot._style[1],str(r))
 			except:
 				line=line.replace("$random"+bot._style[0]+line.split("$random"+bot._style[0])[1].split(bot._style[1])[0]+bot._style[1],"none")
-		while "$roleID"+bot._style[0] in line and time.time() < timeout_start + timeout:
+		while "$roleID"+bot._style[0] in line:
 			try:
 				role = discord.utils.get(guild.roles, name=line.split("$roleID"+bot._style[0])[1].split(bot._style[1])[0])
 				line=line.replace("$roleID"+bot._style[0]+line.split("$roleID"+bot._style[0])[1].split(bot._style[1])[0]+bot._style[1],str(role.id))
